<?php

/**
 * The admin-specific functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    Wc_Whatsapp
 * @subpackage Wc_Whatsapp/admin
 * @author     Sevengits <sevengits@gmail.com>
 */
class Wc_Whatsapp_Admin
{

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of this plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct($plugin_name, $version)
	{

		$this->plugin_name = $plugin_name;
		$this->version = $version;
	}

	/**
	 * Register the stylesheets for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles()
	{

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Wc_Whatsapp_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Wc_Whatsapp_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_style($this->plugin_name, plugin_dir_url(__FILE__) . 'css/wc-whatsapp-admin.css', array(), $this->version, 'all');

		if (!wp_style_is('sgits-admin-common-css', 'enqueued')) {
			wp_enqueue_style('sgits-admin-common', plugin_dir_url(__FILE__) . 'css/common.css', array(), $this->version, 'all');
		}
	}

	/**
	 * Register the JavaScript for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts()
	{

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Wc_Whatsapp_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Wc_Whatsapp_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_script($this->plugin_name, plugin_dir_url(__FILE__) . 'js/wc-whatsapp-admin.js', array('jquery'), $this->version, false);
	}

	/**
	 * Custom type settings function
	 * @since 1.0.0
	 *
	 * @param string $section: unique id for settings 
	 * @param string $field
	 * @return array()
	 */
	function get_settings_statuses($section = '', $statuses = array())
	{
		$result = array();
		foreach ($statuses as $status_key => $status_label) {
			$id_prefix = $section . '_' . str_replace('-', '_', $status_key);
			$label_description = ucfirst(trim(str_replace('-', ' ', str_replace('wc', '', $status_key)) . ' order notification sent to the customer when orders have been marked ' . strtolower($status_label) . '.'));
			$result[] = array(
				array(
					'id' => $id_prefix . '_label',
					'name' => __($status_label, 'wc-whatsapp'),
					'type' => 'label',
					'desc' => __($label_description, 'wc-whatsapp'),
					'desc_tip'	=> true
				),
				array(
					'id' => $id_prefix . '_enabled',
					'type' => "sg_switch",

				),
				array(
					'id' => $id_prefix . '_message_id',
					'type' => "text",
					'placeholder' => 'template name',
					'desc_tip'	=> true,
					'default' => 'hello_world'
				),
				array(
					'id' => $id_prefix . '_lang_code',
					'type' => "select",
					'options' =>  array(
						"af" => "Afrikaans",
						"sq" => "Albanian",
						"ar" => "Arabic",
						"az" => "Azerbaijani",
						"bn" => "Bengali",
						"bg" => "Bulgarian",
						"ca" => "Catalan",
						"zh_CN" => "Chinese (CHN)",
						"zh_HK" => "Chinese (HKG)",
						"zh_TW" => "Chinese (TAI)",
						"hr" => "Croatian",
						"cs" => "Czech",
						"da" => "Danish",
						"nl" => "Dutch",
						"en" => "English",
						"en_GB" => "English (UK)",
						"en_US" => "English (US)",
						"et" => "Estonian",
						"fil" => "Filipino",
						"fi" => "Finnish",
						"fr" => "French",
						"ka" => "Georgian",
						"de" => "German",
						"el" => "Greek",
						"gu" => "Gujarati",
						"ha" => "Hausa",
						"he" => "Hebrew",
						"hi" => "Hindi",
						"hu" => "Hungarian",
						"id" => "Indonesian",
						"ga" => "Irish",
						"it" => "Italian",
						"ja" => "Japanese",
						"kn" => "Kannada",
						"kk" => "Kazakh",
						"rw_RW" => "Kinyarwanda",
						"ko" => "Korean",
						"ky_KG" => "Kyrgyz (Kyrgyzstan)",
						"lo" => "Lao",
						"lv" => "Latvian",
						"lt" => "Lithuanian",
						"mk" => "Macedonian",
						"ms" => "Malay",
						"ml" => "Malayalam",
						"mr" => "Marathi",
						"nb" => "Norwegian",
						"fa" => "Persian",
						"pl" => "Polish",
						"pt_BR" => "Portuguese (BR)",
						"pt_PT" => "Portuguese (POR)",
						"pa" => "Punjabi",
						"ro" => "Romanian",
						"ru" => "Russian",
						"sr" => "Serbian",
						"sk" => "Slovak",
						"sl" => "Slovenian",
						"es" => "Spanish",
						"es_AR" => "Spanish (ARG)",
						"es_ES" => "Spanish (SPA)",
						"es_MX" => "Spanish (MEX)",
						"sw" => "Swahili",
						"sv" => "Swedish",
						"ta" => "Tamil",
						"te" => "Telugu",
						"th" => "Thai",
						"tr" => "Turkish",
						"uk" => "Ukrainian",
						"ur" => "Urdu",
						"uz" => "Uzbek",
						"vi" => "Vietnamese",
						"zu" => "Zulu"
					),
					'default' => 'en_US'
				),
				array(
					'id' => $id_prefix . '_params',
					'type' => "text",
					'placeholder' => 'Variables',
					'default' => '',
					'desc' => __($this->sg_wcw_get_msg_params(), 'wc-whatsapp'),
					'desc_tip'	=> true
				),
			);
		}
		return $result;
	}

	/**
	 * get selected order status from array of statuses
	 * @since 1.0.0
	 *
	 * @param array $statuses
	 * @param string $status
	 * @return void
	 */
	function get_filtered_status($statuses = array(), $status = '')
	{
		foreach ($statuses as $status_key => $status_value) {
			if (str_replace('wc-', '', $status_key) === $status) {
				return array($status_key => $status_value);
			}
		}
		return array();
	}

	/**
	 * Plugin configuration settings 
	 * @since 1.0.0
	 *
	 * @param [type] $settings
	 * @param [type] $current_section
	 * @return void
	 */
	public function sgits_wc_whatsapp_settings($settings, $current_section)
	{
		if ('sg_wc_whatsapp_settings' == $current_section) {
			$settings = array(
				array(
					'type' => 'title',
					'name' => __('WC Whatsapp', 'wc-whatsapp'),
					'desc'	=>	__('WC Whatsapp configuration', 'wc-whatsapp'),
					'id'	=> 'sg_wc_whatsapp_tab',
				),
				array(
					'id' => 'sg_wcw_whatsapp_api',
					'type' => 'text',
					'name' => __('Whatsapp Access Token', 'wc-whatsapp'),
					'desc' => __('Access token will be get from WhatsApp API setup. <a href="https://sevengits.com/docs/wc-whatsapp/" target="_blank">learn more.</a>', 'wc-whatsapp'),
					'desc_tip'	=> false
				),


				array(
					'id' => 'sg_wcw_whatsapp_number_id',
					'type' => 'text',
					'name' => __('Phone number ID', 'wc-whatsapp'),
					'placeholder' => __('Whatsapp admin number id', 'wc-whatsapp'),
					'default' => '',
					'desc' => __('Unique number given by whatspp. <a href="https://sevengits.com/docs/wc-whatsapp/" target="_blank">learn more.</a>', 'wc-whatsapp'),
					'desc_tip'	=> false
				),

				array(
					'id' => 'sg_wcw_enable_whatsapp_updates',
					'type' => 'sg_wcw_inline',
					'name' => __('Enable opt-in checkbox', 'wc-whatsapp'),
					'desc' => __('Add an opt-in checkbox for WhatsApp notifications during checkout.', 'wc-whatsapp'),
					'desc_tip'	=> true,
					'options' => array(
						array(
							'id' => 'sg_wcw_enable_checkbox_status',
							'type' => 'checkbox',
							'name' => __('on/off', 'wc-whatsapp'),
							'default' => true,

						),
						array(
							'id' => 'sg_wcw_enable_checkbox_label',
							'type' => 'text',
							'name' => __('checkout field name', 'wc-whatsapp'),
							'placeholder' => __('checkout field name', 'wc-whatsapp'),
							'default' => 'Get order updates on whatsapp',

						),
						array(
							'id' => 'sg_wcw_enable_checkbox_priority',
							'type' => 'number',
							'name' => __('Priority', 'wc-whatsapp'),
							'placeholder' => __('enable notification field priority', 'wc-whatsapp'),
							'default' => 101,

						),
					)
				),

				array(
					'type'	=> 'sectionend',
					'name'	=> 'end_section',
					'id'	=> 'sgits_wc_whatsapp_api'
				),
				array(
					'id' => 'sg_wcw_woocommerce',
					'type' => 'sg_wcw_config_per_status',
					'name' => __('Woocommerce', 'wc-whatsapp'),
					'fields' => $this->get_settings_statuses('sg_wcw_woocommerce_config_per_status', wc_get_order_statuses()),
					'desc_tip'	=> true

				),
				array(
					'type'	=> 'sectionend',
					'name'	=> 'end_section',
					'id'	=> 'sgits_wc_whatsapp_settings'
				),
			);
		}
		return $settings;
	}

	/**
	 * Woocommerce advanced tab custom sub tab
	 * @since 1.0.0
	 *
	 * @param [type] $settings_tab
	 * @return void
	 */
	public function sgits_wc_whatsapp_tab($settings_tab)
	{

		$settings_tab['sg_wc_whatsapp_settings'] = __('WC Whatsapp', 'wc-whatsapp');
		return $settings_tab;
	}

	/**
	 * Custom display for settings type of "sg_wc_whatsapp_config_per_status"
	 * @since 1.0.0
	 *
	 * @param [type] $links
	 * @return void
	 */
	public function sg_wc_whatsapp_config_settings($links)
	{
?>
		<h3><?php echo $links['name']; ?></h3>
		<table class="wc_emails widefat" cellspacing="0">
			<thead>
				<tr>
					<th class="wc-email-settings-table-name"><?php _e('Order status', 'wc-whatsapp'); ?></th>
					<th class="wc-email-settings-table-email_type"><?php _e('Enable / disable', 'wc-whatsapp'); ?></th>
					<th class="wc-email-settings-table-recipient"><?php _e('Language', 'wc-whatsapp'); ?></th>
					<th class="wc-email-settings-table-recipient"><?php _e('Template name', 'wc-whatsapp'); ?></th>
					<th class="wc-email-settings-table-recipient"><?php _e('Parameters', 'wc-whatsapp'); ?></th>
				</tr>
			</thead>
			<tbody>
				<?php
				foreach ($links['fields'] as $fields) {
				?>
					<tr>
						<?php

						foreach ($fields as $field) {
							if ($field['type'] !== 'label') {
								$field['value'] = '';
								if (array_key_exists('default', $field) && $field['value'] === '') {
									$field['value'] = $field['default'];
								}
								$field['value'] = get_option($field['id'], '');
							}
							switch ($field['type']) {
								case 'label':
						?>
									<td class="wc-email-settings-table-name with-tooltip">
										<span><?php _e($field['name'], 'wc-whatsapp'); ?></span>
										<?php
										if (isset($field['desc'])) {
											if (isset($field['desc_tip'])) {
												if ($field['desc_tip'] === true) {
													echo wc_help_tip(esc_html($field['desc']));
												} else {
										?>
													<span><?php _e($field['desc'], 'wc-whatsapp'); ?></span>
												<?php
												}
											} else {
												?>
												<span><?php _e($field['desc'], 'wc-whatsapp'); ?></span>
										<?php
											}
										}
										?>
									</td>
								<?php
									break;
								case 'sg_switch':
								?>
									<td class="wc-email-settings-table-switch sg-switch-checkbox">
										<input id="<?php _e($field['id']); ?>" <?php if ($field['value'] === 'yes') echo 'checked'; ?> type="checkbox" name="<?php _e($field['id']); ?>">
										<label for="<?php _e($field['id']); ?>" class="switch"></label>
									</td>
								<?php
									break;
								case 'checkbox':
								?>
									<td class="">
										<input id="<?php _e($field['id']); ?>" <?php if ($field['value'] === 'yes') echo 'checked'; ?> type="checkbox" name="<?php _e($field['id']); ?>">
									</td>
								<?php
									break;
								case 'text':

								?>
									<td class="wc-email-settings-table-recipient">
										<input type="text" name="<?php _e($field['id']); ?>" id="<?php _e($field['id']); ?>" value="<?php _e($field['value'], 'wc-whatsapp'); ?>" placeholder="<?php _e($field['placeholder']); ?>">
										<?php
										if (isset($field['desc'])) {
											if (isset($field['desc_tip'])) {
												if ($field['desc_tip'] === true) {
													echo wc_help_tip(esc_html($field['desc']));
												} else {
										?>
													<span><?php _e($field['desc'], 'wc-whatsapp'); ?></span>
												<?php
												}
											} else {
												?>
												<span><?php _e($field['desc'], 'wc-whatsapp'); ?></span>
										<?php
											}
										}
										?>
									</td>
								<?php
									break;
								case 'textarea':

								?>
									<td class="wc-email-settings-table-recipient with-tooltip">
										<textarea name="" name="<?php _e($field['id']); ?>" id="<?php _e($field['id']); ?>" value="<?php _e($field['value'], 'wc-whatsapp'); ?>" placeholder="<?php _e($field['placeholder']); ?>"></textarea>
										<?php
										if (isset($field['desc'])) {
											if (isset($field['desc_tip'])) {
												if ($field['desc_tip'] === true) {
													echo wc_help_tip(esc_html($field['desc']));
												} else {
										?>
													<span><?php _e($field['desc'], 'wc-whatsapp'); ?></span>
												<?php
												}
											} else {
												?>
												<span><?php _e($field['desc'], 'wc-whatsapp'); ?></span>
										<?php
											}
										}
										?>
									</td>
								<?php

									break;
								case 'select':
									$field_value = isset($field['default']) ? $field['default'] : '';
									$field_value = get_option($field['id'], $field_value);
								?>
									<td>
										<select name="<?php _e($field['id']); ?>" id="<?php _e($field['id']); ?>">
											<?php
											foreach ($field['options'] as $option_value => $option_text) {
												_e('<option ' . (($option_value === $field_value) ? 'selected' : '') . ' value="' . $option_value . '">' . $option_text . '</option>');
											}
											?>
										</select>
									</td>
					<?php
									break;
								default:
									# code...
									break;
							}
						}
						echo "</tr>";
					}
					?>
			</tbody>
		</table>
	<?php
	}

	function sg_wcw_inline_settings($links)
	{
	?>
		<table class="form-table">

			<tbody>
				<tr valign="top">
					<th scope="row" class="titledesc">
						<label for="<?php _e($links['id']); ?>"><?php _e($links['name']); ?> </label>
						<?php
						if (isset($links['desc'])) {
							if (isset($links['desc_tip'])) {
								if ($links['desc_tip'] === true) {
									echo wc_help_tip(esc_html($links['desc']));
								} else {
						?>
									<span><?php _e($links['desc'], 'wc-whatsapp'); ?></span>
								<?php
								}
							} else {
								?>
								<span><?php _e($links['desc'], 'wc-whatsapp'); ?></span>
						<?php
							}
						}
						?>
					</th>
					<td class="forminp inline-nospace-fields forminp-text">
						<?php
						if (isset($links['options'])) :
							foreach ($links['options'] as $field) {
								$value = ($field['type'] === 'checkout') ? 'no' : '';
								if (isset($field['default'])) {
									$value = $field['default'];
								}
								$value = get_option($field['id'], $value);
						?>
								<div class="list-block">
									<label for="<?php _e($field['id']); ?>"><?php _e(isset($field['name']) ? $field['name'] : ''); ?></label>
									<?php
									switch ($field['type']) {
										case 'checkbox':
									?>
											<input type="checkbox" name="<?php _e($field['id']); ?>" id="<?php _e($field['id']); ?>" class="sg-wcw-checkbox" <?php _e(($value !== 'no') ? 'checked' : ''); ?>>
										<?php
											break;

										default:
										?>
											<input type="<?php _e($field['type']); ?>" name="<?php _e($field['id']); ?>" id="<?php _e($field['id']); ?>" class="sg-wcw-input-<?php _e($field['type']); ?>" value="<?php _e($value); ?>">
									<?php
											break;
									}
									?>
								</div>
						<?php
							}
						endif;
						?>

					</td>

				</tr>
			</tbody>
		</table>
<?php

	}

	/**
	 * get order status options and id prefix
	 * @since 1.0.0
	 *
	 * @return void
	 */
	public function get_order_status_settings()
	{
		$result = array();
		$result = array(
			array('sg_wcw_woocommerce_config_per_status', wc_get_order_statuses())
		);
		return $result;
	}



	function sg_wcw_get_msg_params($type = "keys", $method = "string", $order = null, $options = '')
	{
		$param_keys = array();
		$param_values = array();
		$additional_params = apply_filters("sg_wcw_msg_additional_params", array(), $order);
		$params_list = array(
			"site_title" => get_bloginfo('name'),
			"site_address" => get_bloginfo('wpurl'),
			"site_url" => get_bloginfo('url'),
			"order_number" => 0,
			"order_date" => '',
		);
		$params_list = array_merge($params_list, $additional_params);
		if ($order === null) {
			$param_keys = array_keys($params_list);
		} else {
			$params_list['order_number'] = $order->get_id();
			$params_list['order_date'] = $order->get_date_created()->date("F j, Y");
		}

		if ($options !== '') {
			foreach ($params_list as $param_key => $param_value) {
				if (str_contains($options, $param_key)) {
					$param_keys[] = $param_key;
					$param_values[] = $param_value;
				}
			}
		}
		if ($type === 'keys') {
			if ($method === 'string') {
				return implode(", ", $param_keys);
			}
			return $param_keys;
		}
		if ($method === 'string') {
			return implode(", ", $param_values);
		}
		return $param_values;
	}

	/**
	 * Save custom options for settings type sg_wc_whatsapp_config_per_status. 
	 * @since 1.0.0
	 *
	 * @return void
	 */
	public function sgits_wc_whatsapp_save_custom_type_fields()
	{
		$options = array();

		$options[] = array('key' => 'sg_wcw_enable_checkbox_status', 'type' => 'checkbox');
		$options[] = array('key' => 'sg_wcw_enable_checkbox_label', 'type' => 'text');
		$options[] = array('key' => 'sg_wcw_enable_checkbox_priority', 'type' => 'text');

		foreach ($options as $option) {
			if ($option['type'] === 'checkbox') {
				if (isset($_POST[$option['key']])) {
					update_option($option['key'], sanitize_text_field('yes'));
				} else {
					update_option($option['key'], sanitize_text_field('no'));
				}
			} else {
				if (isset($_POST[$option['key']])) {
					update_option($option['key'], sanitize_text_field($_POST[$option['key']]));
				}
			}
		}
		$post_key_prefixes = array_merge(array(), $this->get_order_status_settings());
		foreach ($post_key_prefixes as $post_key) {
			$field_list = array();
			$field_list = array_merge($field_list, $this->get_settings_statuses($post_key[0], $post_key[1]));
			if (!empty($field_list)) {
				foreach ($field_list as $fields) {
					foreach ($fields as $field) {
						if (isset($_POST[$field['id']])) {
							if ($field['type'] === 'checkbox' || $field['type'] === 'sg_switch') {

								update_option($field['id'], sanitize_text_field('yes'));
							} else {
								update_option($field['id'], sanitize_text_field($_POST[$field['id']]));
							}
						} else if ($field['type'] === 'checkbox') {
							update_option($field['id'], sanitize_text_field('no'));
						} else {
							update_option($field['id'], sanitize_text_field(''));
						}
					}
				}
			}
		}
	}

	/**
	 * Send whatsapp message
	 * @since 1.0.0
	 *
	 * @param [type] $message_id
	 * @param string $order_id
	 * @param array $order_status = array(old => OLD-STATUS, new => NEW-STATUS)
	 * @return void
	 */
	public function sg_whatsapp_trigger_msg($message_id, $order_id = '', $order_status = array())
	{
		if (get_option('sg_wcw_whatsapp_api', '') !== '' && $order_id !== '') {
			$order = wc_get_order($order_id);
			$token = get_option('sg_wcw_whatsapp_api', '');
			$number = array();
			if (!empty($order->get_billing_phone())) {
				$number[] = $order->get_billing_phone();
			}
			if (!empty($order->get_shipping_phone()) && $order->get_billing_phone() !== $order->get_shipping_phone()) {
				$number[] = $order->get_shipping_phone();
			}
			if (count($number) > 0) {
				$url = "https://graph.facebook.com/v17.0/120107201075851/messages?access_token=$token";
				$options = array(
					'headers'     => array(
						'Authorization' => $token,
					),
					'body'        => array(
						'messaging_product' => "whatsapp",
						'to' => $number[0],
						'type' => "template",
						'template' => array(
							'name' => $message_id,
							'language' => array('code' => "en_US")
						)
					)
				);
				$request = wp_remote_post($url, $options);
				if (is_wp_error($request) || wp_remote_retrieve_response_code($request) != 200) {
					error_log(print_r($request, true));
				} else {
					$response = wp_remote_retrieve_body($request);
					$msg_id = json_decode($response)->messages[0]->id;
					$msg = __("Whatsapp message sent for " . $order_status['new'] . " Whatsapp Message id: " . $msg_id, 'wc-whatsapp');
					$order->add_order_note($msg, $is_customer_note = 0, $added_by_user = false);
				}
			}
		}
	}

	/**
	 * Send whatsapp message trigger if order status changed
	 *
	 * @param [type] $order_id
	 * @param [type] $old_status
	 * @param [type] $new_status
	 * @return void
	 */
	public function sgits_wc_whatsapp_send($order_id, $old_status, $new_status)
	{
		foreach (array_merge(array(), $this->get_order_status_settings()) as $get_order_status_settings) {
			$get_filtered_status = array_merge(array(), $this->get_filtered_status($get_order_status_settings[1], $new_status));
			if (count($get_filtered_status) > 0) {
				$get_filtered_status = str_replace('-', '_', array_keys($get_filtered_status)[0]);
				$field_id_prefix = $get_order_status_settings[0] . '_' . $get_filtered_status;
				if (get_option($field_id_prefix . '_message_id', '') !== '' && get_option($field_id_prefix . '_enabled', 'no') === 'yes') {
					$order_status = array("old" => $old_status, "new" =>  $new_status);
					$this->sg_whatsapp_trigger_msg(get_option($field_id_prefix . '_message_id', ''), $order_id, $order_status);
				}
			}
		}
	}

	public function sgits_wcw_merge_links($old_list, $new_list, $position = "end")
	{
		$settings = array();
		foreach ($new_list as $name => $item) {
			$target = (array_key_exists("target", $item)) ? $item['target'] : '';
			$classList = (array_key_exists("classList", $item)) ? $item['classList'] : '';
			$settings[$name] = sprintf('<a href="%s" target="' . $target . '" class="' . $classList . '">%s</a>', esc_url($item['link'], $this->plugin_name), esc_html__($item['name'], $this->plugin_name));
		}
		if ($position !== "start") {
			// push into $links array at the end
			return array_merge($old_list, $settings);
		} else {
			return array_merge($settings, $old_list);
		}
	}


	public function sgits_wcw_links_below_title_begin($links)
	{
		// if plugin is installed $links listed below the plugin title in plugins page. add custom links at the begin of list

		$link_list = array(
			'settings' => array(
				"name" => __('Settings', 'wc-whatsapp'),
				"classList" => "",
				"link" => admin_url('admin.php?page=wc-settings&tab=advanced&section=sg_wc_whatsapp_settings')
			)
		);
		return $this->sgits_wcw_merge_links($links, $link_list, "start");
	}

	public function sgits_wcw_links_below_title_end($links)
	{
		// if plugin is installed $links listed below the plugin title in plugins page. add custom links at the end of list
		$link_list = array(
			'buy-pro' => array(
				"name" => __('Buy Premium', 'wc-whatsapp'),
				"classList" => "pro-purchase get-pro-link",
				"target" => '_blank',
				"link" => 'https://sevengits.com/plugin/wc-whatsapp/?utm_source=Wordpress&utm_medium=plugins-link&utm_campaign=Free-plugin'
			)
		);
		return $this->sgits_wcw_merge_links($links, $link_list, "end");
	}

	function sgits_wcw_plugin_description_below_end($links, $file)
	{
		if (strpos($file, 'wc-whatsapp.php') !== false) {
			$new_links = array(
				'pro' => array(
					"name" => __('Buy Premium', 'wc-whatsapp'),
					"classList" => "pro-purchase get-pro-link",
					"target" => '_blank',
					"link" => 'https://sevengits.com/plugin/wc-whatsapp/?utm_source=dashboard&utm_medium=plugins-link&utm_campaign=Free-plugin'
				),
				'docs' => array(
					"name" => __('Docs', 'wc-whatsapp'),
					"target" => '_blank',
					"link" => 'https://sevengits.com/docs/wc-whatsapp/?utm_source=dashboard&utm_medium=plugins-link&utm_campaign=Free-plugin'
				),
				'support' => array(
					"name" => __('Free Support', 'wc-whatsapp'),
					"target" => '_blank',
					"link" => 'https://sevengits.com/contact//?utm_source=dashboard&utm_medium=plugins-link&utm_campaign=Free-plugin'
				),

			);
			$links = $this->sgits_wcw_merge_links($links, $new_links, "end");
		}

		return $links;
	}
}
