<?php

/**
 * The public-facing functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the public-facing stylesheet and JavaScript.
 *
 * @package    Wc_Whatsapp
 * @subpackage Wc_Whatsapp/public
 * @author     Sevengits <sevengits@gmail.com>
 */
class Wc_Whatsapp_Public
{

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of the plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct($plugin_name, $version)
	{

		$this->plugin_name = $plugin_name;
		$this->version = $version;
	}

	/**
	 * Register the stylesheets for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles()
	{

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Wc_Whatsapp_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Wc_Whatsapp_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_style($this->plugin_name, plugin_dir_url(__FILE__) . 'css/wc-whatsapp-public.css', array(), $this->version, 'all');
	}

	/**
	 * Register the JavaScript for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts()
	{

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Wc_Whatsapp_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Wc_Whatsapp_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_script($this->plugin_name, plugin_dir_url(__FILE__) . 'js/wc-whatsapp-public.js', array('jquery'), $this->version, false);
	}
	function wcw_enable_notification($fields)
	{
		if (get_option('sg_wcw_enable_checkbox_status', 'no') === 'yes') {
			$fields['billing']['billing_wcw_notification'] = array(
				"label" => get_option('sg_wcw_enable_checkbox_label', 'Get order updates on whatsapp'),
				"type" => "checkbox",
				"required" => false,
				"class" => array("form-row-wide"),
				"default" => true,
				"priority" => get_option('sg_wcw_enable_checkbox_priority', 101)
			);
		}
		return $fields;
	}

	function wcw_country_prefix_in_billing_phone()
	{
		$calling_code = '';
		$country_code = isset($_POST['country_code']) ? $_POST['country_code'] : '';
		if ($country_code) {
			$calling_code = WC()->countries->get_country_calling_code($country_code);
			$calling_code = is_array($calling_code) ? $calling_code[0] : $calling_code;
		}
		echo $calling_code;
		die();
	}

	function scripts_for_adding_country_prefix_on_billing_phone()
	{
		if (get_option('sg_wcw_enable_checkbox_status', 'no') === 'yes') {
?>
			<script type="text/javascript">
				(function(jQuery) {
					jQuery(document.body).on('updated_checkout', function(data) {
						var ajax_url = "<?php echo admin_url('admin-ajax.php'); ?>",
							country_code = jQuery('#billing_country').val();
						var ajax_data = {
							action: 'append_country_prefix_in_billing_phone',
							country_code: jQuery('#billing_country').val()
						};
						jQuery.post(ajax_url, ajax_data, function(response) {
							jQuery('#billing_phone').val(response);
						});
					});
				})(jQuery);
			</script>
<?php
		}
	}
}
