<?php

/**
 * @link              https://https://sevengits.com/
 * @since             1.0.0
 * @package           Wc_Whatsapp
 *
 * @wordpress-plugin
 * Plugin Name:       WC whatsapp - WhatsApp Business API Integration for WooCommerce
 * Plugin URI:        https://sevengits.com/plugin/wc-whatsapp
 * Description:       Wc whatsapp integrates the WhatsApp Business API with WooCommerce and automate your business communication by sending real-time updates, and order status notifications directly to your customers' WhatsApp accounts
 * Version:           1.0.0
 * Author:            Sevengits
 * Author URI:        https://https://sevengits.com/
 * License:           GPL-2.0+
 * License URI:       http://www.gnu.org/licenses/gpl-2.0.txt
 * Text Domain:       wc-whatsapp
 * Domain Path:       /languages
 * WC Requires at least: 3.7
 * WC Tested up to:      7.9
 */

// If this file is called directly, abort.
if (!defined('WPINC')) {
	die;
}

/**
 * Currently plugin version.
 * Start at version 1.0.0 and use SemVer - https://semver.org
 * Rename this for your plugin and update it as you release new versions.
 */

if (!defined('WC_WHATSAPP_VERSION')) {
	define('WC_WHATSAPP_VERSION', '1.0.0');
}
if (!defined('WC_WHATSAPP_BASE')) {
	define('WC_WHATSAPP_BASE', plugin_basename(__FILE__));
}

/**
 * The code that runs during plugin activation.
 * This action is documented in includes/class-wc-whatsapp-activator.php
 */
function activate_wc_whatsapp()
{
	require_once plugin_dir_path(__FILE__) . 'includes/class-wc-whatsapp-activator.php';
	Wc_Whatsapp_Activator::activate();
}

/**
 * The code that runs during plugin deactivation.
 * This action is documented in includes/class-wc-whatsapp-deactivator.php
 */
function deactivate_wc_whatsapp()
{
	require_once plugin_dir_path(__FILE__) . 'includes/class-wc-whatsapp-deactivator.php';
	Wc_Whatsapp_Deactivator::deactivate();
}

register_activation_hook(__FILE__, 'activate_wc_whatsapp');
register_deactivation_hook(__FILE__, 'deactivate_wc_whatsapp');

/**
 * The core plugin class that is used to define internationalization,
 * admin-specific hooks, and public-facing site hooks.
 */
require plugin_dir_path(__FILE__) . 'includes/class-wc-whatsapp.php';

/**
 * Begins execution of the plugin.
 *
 * Since everything within the plugin is registered via hooks,
 * then kicking off the plugin from this point in the file does
 * not affect the page life cycle.
 *
 * @since    1.0.0
 */
function run_wc_whatsapp()
{

	$plugin = new Wc_Whatsapp();
	$plugin->run();
}
if(function_exists('run_wc_whatsapp')){
	run_wc_whatsapp();
}


